@@ -72,36 +72,61 @@ fetch_data <- function(api_url, cycle, pagesize_n, clean, page_n, n_results, key
   image <- ""
   topic <- ""
 
+  # Define a full set of browser headers
+  headers <- httr::add_headers(
+    `User-Agent` = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36",
+    `Accept` = "application/json, text/javascript, */*; q=0.01",
+    `Accept-Language` = "en-US,en;q=0.9",
+    `X-Requested-With` = "XMLHttpRequest",
+    `Referer` = "https://www.justice.gov/",
+    `Connection` = "keep-alive"
+  )
+
   out <- data.frame()
-  while(nrow(out) < n_results) {
+  while (nrow(out) < n_results) {
 
     results <- data.frame()
-    for(i in 1:cycle) {
-      page_n = page_n + 1
-      raw_data <- GET(paste0(api_url, "&page=", page_n))
-      Sys.sleep(.2)
+    for (i in 1:cycle) {
+      page_n <- page_n + 1
+
+      response <- httr::GET(
+        url = paste0(api_url, "&page=", page_n),
+        headers
+      )
+
+      Sys.sleep(0.2)
+
+      # Optional: inspect raw content for debugging
+      # cat(httr::content(response, "text", encoding = "UTF-8"))
+
+      data <- jsonlite::fromJSON(
+        httr::content(response, as = "text", encoding = "UTF-8"),
+        flatten = TRUE
+      )
 
-      data <- fromJSON(rawToChar(raw_data$content), flatten = TRUE)
       df <- data$results
 
-      if(clean == TRUE) {
+      if (clean == TRUE) {
         df$body <- remove_tags(df$body)
         df$teaser <- remove_tags(df$teaser)
         df$body <- remove_breaks(df$body)
-        df$body <- str_trim(df$body) }
+        df$body <- stringr::str_trim(df$body)
+      }
 
-      results <- bind_rows(results, df) }
+      results <- dplyr::bind_rows(results, df)
+    }
 
-    if(!(is.null(keyword))) {
-      results <- keyword_search(results, keyword) }
+    if (!is.null(keyword)) {
+      results <- keyword_search(results, keyword)
+    }
 
     results <- slicey(results, search_direction, n_results)
-
-    out <- bind_rows(out, results) }
+    out <- dplyr::bind_rows(out, results)
+  }
 
   out <- slicey(out, search_direction, n_results)
+  out <- out %>% dplyr::select(-image, -topic)
 
-  out <- out %>%
-    select(-image, -topic)
+  return(out)
+}
 
-  return(out) }
